# Lambda Labs Provider

The **Lambda Labs Provider** is an implementation of the `Provider` interface in Orkestr. It integrates with the Lambda Labs cloud platform to manage infrastructure and services.

## Environment Variables

The Lambda Labs provider uses the following environment variables:

- `LAMBDA_API_KEY`: Your Lambda Labs API key.
